# -*- mode: python; coding: utf-8 -*-
# Copyright (C) 2017-2019 by BDE ENS Paris-Saclay
# SPDX-License-Identifier: GPL-3.0-or-later

from django.contrib import admin
from django.contrib.auth.admin import UserAdmin as BaseUserAdmin
from django.utils.translation import ugettext_lazy as _
from reversion.admin import VersionAdmin

from .models import User, Right, Adhesion, ListRight, Clef, Request


class RequestAdmin(admin.ModelAdmin):
    list_display = ('user', 'type', 'created_at', 'expires_at')


class RightAdmin(VersionAdmin):
    list_display = ('user', 'right')


class ClefAdmin(VersionAdmin):
    list_display = ('proprio', 'nom')


class AdhesionAdmin(VersionAdmin):
    list_display = ('annee_debut', 'annee_fin')


class ListRightAdmin(VersionAdmin):
    list_display = ('listright',)


class UserAdmin(VersionAdmin, BaseUserAdmin):
    # Customize admin to add more fields
    fieldsets = (
        (None, {'fields': ('username', 'password')}),
        (_('Personal info'), {'fields': ('first_name', 'last_name', 'email',
                                         'telephone', 'address', 'comment')}),
        (_('Permissions'), {'fields': ('is_active', 'is_staff', 'is_superuser',
                                       'groups', 'user_permissions',
                                       'maxemprunt')}),
        (_('Important dates'), {'fields': ('last_login', 'date_joined')}),
    )


admin.site.register(User, UserAdmin)
admin.site.register(Request, RequestAdmin)
admin.site.register(ListRight, ListRightAdmin)
admin.site.register(Right, RightAdmin)
admin.site.register(Adhesion, AdhesionAdmin)
admin.site.register(Clef, ClefAdmin)
